#!/bin/sh

# Copyright (C) 2004-2016 QVidium Technologies, Inc. All rights reserved.

CONF_FILE=/disk/netfilter/netfilter.conf
WHITELIST=/disk/netfilter/whitelist
LIST=$(seq 1 15)

if [ "$QUERY_STRING" = "" ] ; then

    [ -f $CONF_FILE ] && . $CONF_FILE

    NF_ENABLE_TRUE_CHECKED=
    NF_ENABLE_FALSE_CHECKED=
    case "$NETFILTER_ENABLED" in
        Yes) NF_ENABLE_TRUE_CHECKED=checked ;;
        *) NF_ENABLE_FALSE_CHECKED=checked ;;
    esac

    NF_SUPPORT_TRUE_CHECKED=
    NF_SUPPORT_FALSE_CHECKED=
    case "$NETFILTER_SUPPORT_ENABLED" in
        No) NF_SUPPORT_FALSE_CHECKED=checked ;;
        *) NF_SUPPORT_TRUE_CHECKED=checked ;;
    esac

    NF_LOG_TRUE_CHECKED=
    NF_LOG_FALSE_CHECKED=
    case "$NETFILTER_LOG_DROPPED" in
        Yes) NF_LOG_TRUE_CHECKED=checked ;;
        *) NF_LOG_FALSE_CHECKED=checked ;;
    esac

    NF_ALL_PRI_NET_TRUE_CHECKED=
    NF_ALL_PRI_NET_FALSE_CHECKED=
    case "$NETFILTER_ALL_PRIVATE_NETWORKS" in
        Yes) NF_ALL_PRI_NET_TRUE_CHECKED=checked ;;
        *) NF_ALL_PRI_NET_FALSE_CHECKED=checked ;;
    esac

    cat <<!
Content-type: text/html

<html>
<head>
<title>Firewall Config</title>
<link href="/style.css" type="text/css" rel="stylesheet">
</head>
<body>
 <h2>Firewall Configuration</h2>
 <form action="/cgi-bin/firewall/config.cgi">
  <table class=props cellSpacing="1" cellPadding="2" border="1">
   <tr align="left">
    <td colspan=2>Firewall</td>
    <td>
     <input type=radio name="NETFILTER_ENABLED" value="Yes" $NF_ENABLE_TRUE_CHECKED>On
     <input type=radio name="NETFILTER_ENABLED" value="No" $NF_ENABLE_FALSE_CHECKED>Off
    </td>
   </tr>
   <tr align="left">
    <td colspan=2>Technical Support Access</td>
    <td>
     <input type=radio name="NETFILTER_SUPPORT_ENABLED" value="Yes" $NF_SUPPORT_TRUE_CHECKED>Yes
     <input type=radio name="NETFILTER_SUPPORT_ENABLED" value="No" $NF_SUPPORT_FALSE_CHECKED>No
    </td>
   </tr>
   <tr align="left">
    <td colspan=2>Log Dropped Packets</td>
    <td>
     <input type=radio name="NETFILTER_LOG_DROPPED" value="Yes" $NF_LOG_TRUE_CHECKED>Yes
     <input type=radio name="NETFILTER_LOG_DROPPED" value="No" $NF_LOG_FALSE_CHECKED>No
    </td>
   </tr>
   <tr align="left">
    <td colspan=2>All Private Networks</td>
    <td>
     <input type=radio name="NETFILTER_ALL_PRIVATE_NETWORKS" value="Yes" $NF_ALL_PRI_NET_TRUE_CHECKED>Yes
     <input type=radio name="NETFILTER_ALL_PRIVATE_NETWORKS" value="No" $NF_ALL_PRI_NET_FALSE_CHECKED>No
    </td>
   </tr>
   <tr align=center>
    <td colSpan="3" nowrap><strong><font size="4">Whitelist</font></strong></td>
   </tr>
   <tr align=center>
    <th colSpan="2" nowrap><strong><font size="2">Subnet Address</font></strong></th>
    <th cnowrap><strong><font size="2">Comment</font></strong></th>
  </tr>
!

    for NUM in $LIST
    do
        eval WL${NUM}=
        eval WL${NUM}_EN=0
    done
    [ ! -f $WHITELIST ] && > $WHITELIST
    NUM=1
    FILE=/tmp/netfilter$$
    grep '^[01],' $WHITELIST > $FILE
    while read line
    do
        eval `echo "$line" | tr [\&\!\@\#\%\^\ ] '_' | sed 's/^/WL'$NUM'_EN=/;s/,/\nWL'$NUM'=/;s/,/\nWL'$NUM'_TAG=/'`
        NUM=$((NUM + 1))
    done < $FILE
    rm $FILE

    for NUM in $LIST
    do
        eval ipaddr=\$WL$NUM
        eval enabled=\$WL${NUM}_EN
        eval TAG=\$WL${NUM}_TAG
        CHECKED=
        [ "$enabled" != 0 -a "$enabled" != 1 ] && enabled=0
        [ "$enabled" = 1 ] && CHECKED=checked
        cat <<!
   <tr>
    <td colSpan="2">
     <input type="checkbox" name="WL${NUM}_EN" value="1" $CHECKED>&nbsp;
     <input type="text" name="WL$NUM" size="25" maxlength="25" value="$ipaddr">
    </td><td>
     <input type="text" name="WL${NUM}_TAG" size="20" maxlength="20" value="$TAG">
    </td>
   </tr>
!
    done

    cat <<!
    </td>
   </tr>
  </table>
  <p>
  <input type=submit value="Change Firewall Configuration">
 </form>
</body>
</html>
!
else
    eval `/usr/local/bin/cgiparse "$QUERY_STRING"`

    cat <<! > $CONF_FILE
NETFILTER_ENABLED=$NETFILTER_ENABLED
NETFILTER_LOG_DROPPED=$NETFILTER_LOG_DROPPED
NETFILTER_SUPPORT_ENABLED=$NETFILTER_SUPPORT_ENABLED
NETFILTER_ALL_PRIVATE_NETWORKS=$NETFILTER_ALL_PRIVATE_NETWORKS
!

    > $WHITELIST
    for NUM in $LIST
    do
        eval ipaddr=\$WL$NUM
        eval enabled=\$WL${NUM}_EN
        eval TAG=\$WL${NUM}_TAG
        TAG=`echo $TAG | tr -d -c [:alnum:]`
       [ "$enabled" = "" ] && enabled=0
        echo $enabled,$ipaddr,$TAG>> $WHITELIST
    done

    sync
    cat <<!
Content-type: text/html

<html>
<head>
<link href="/style.css" type="text/css" rel="stylesheet">
<title>Firewall Status</title>
<body>
<h2>Firewall Status</h2>
!
    if [ "$NETFILTER_ENABLED" = Yes ] ; then
        echo 'Firewall is enabled.<br><pre>'
        sh /disk/netfilter/rc.setup
        echo
    else
        echo 'Firewall is disabled.<br><pre>'
        sh /disk/netfilter/rc.reset
    fi
    iptables -L -n
    cat <<!
</pre>
</body>
</html>
!
fi
